==> kubernetes-model-core-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/NamedContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class NamedContextFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedContextFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedContextFluent<A>{
  public NamedContextFluentImpl() {
  }
  public NamedContextFluentImpl(io.fabric8.kubernetes.api.model.NamedContext instance) {
    this.withContext(instance.getContext()); 
    this.withName(instance.getName()); 
  }
  private io.fabric8.kubernetes.api.model.ContextBuilder context;
  private java.lang.String name;
  
  /**
   * This method has been deprecated, please use method buildContext instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Context getContext() {
    return this.context!=null?this.context.build():null;
  }
  public io.fabric8.kubernetes.api.model.Context buildContext() {
    return this.context!=null?this.context.build():null;
  }
  public A withContext(io.fabric8.kubernetes.api.model.Context context) {
    _visitables.get("context").remove(this.context);
    if (context!=null){ this.context= new io.fabric8.kubernetes.api.model.ContextBuilder(context); _visitables.get("context").add(this.context);} return (A) this;
  }
  public java.lang.Boolean hasContext() {
    return this.context != null;
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContext() {
    return new io.fabric8.kubernetes.api.model.NamedContextFluentImpl.ContextNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContextLike(io.fabric8.kubernetes.api.model.Context item) {
    return new io.fabric8.kubernetes.api.model.NamedContextFluentImpl.ContextNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editContext() {
    return withNewContextLike(getContext());
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContext() {
    return withNewContextLike(getContext() != null ? getContext(): new io.fabric8.kubernetes.api.model.ContextBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContextLike(io.fabric8.kubernetes.api.model.Context item) {
    return withNewContextLike(getContext() != null ? getContext(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedContextFluentImpl that = (NamedContextFluentImpl) o;
    if (context != null ? !context.equals(that.context) :that.context != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(context,  name,  super.hashCode());
  }
  public class ContextNestedImpl<N> extends io.fabric8.kubernetes.api.model.ContextFluentImpl<io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>> implements io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContextNestedImpl(io.fabric8.kubernetes.api.model.Context item) {
      this.builder = new io.fabric8.kubernetes.api.model.ContextBuilder(this, item);
    }
    ContextNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ContextBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ContextBuilder builder;
    public N and() {
      return (N) NamedContextFluentImpl.this.withContext(builder.build());
    }
    public N endContext() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/NamedContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamedContextFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedContextFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedContextFluent<A>{
  public NamedContextFluentImpl() {
  }
  public NamedContextFluentImpl(io.fabric8.kubernetes.api.model.NamedContext instance) {
    this.withContext(instance.getContext()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ContextBuilder context;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContext instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Context getContext() {
    return this.context!=null?this.context.build():null;
  }
  public io.fabric8.kubernetes.api.model.Context buildContext() {
    return this.context!=null?this.context.build():null;
  }
  public A withContext(io.fabric8.kubernetes.api.model.Context context) {
    _visitables.get("context").remove(this.context);
    if (context!=null){ this.context= new io.fabric8.kubernetes.api.model.ContextBuilder(context); _visitables.get("context").add(this.context);} return (A) this;
  }
  public java.lang.Boolean hasContext() {
    return this.context != null;
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContext() {
    return new io.fabric8.kubernetes.api.model.NamedContextFluentImpl.ContextNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContextLike(io.fabric8.kubernetes.api.model.Context item) {
    return new io.fabric8.kubernetes.api.model.NamedContextFluentImpl.ContextNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editContext() {
    return withNewContextLike(getContext());
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContext() {
    return withNewContextLike(getContext() != null ? getContext(): new io.fabric8.kubernetes.api.model.ContextBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContextLike(io.fabric8.kubernetes.api.model.Context item) {
    return withNewContextLike(getContext() != null ? getContext(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedContextFluentImpl that = (NamedContextFluentImpl) o;
    if (context != null ? !context.equals(that.context) :that.context != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(context,  name,  additionalProperties,  super.hashCode());
  }
  public class ContextNestedImpl<N> extends io.fabric8.kubernetes.api.model.ContextFluentImpl<io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>> implements io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContextNestedImpl(io.fabric8.kubernetes.api.model.Context item) {
      this.builder = new io.fabric8.kubernetes.api.model.ContextBuilder(this, item);
    }
    ContextNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ContextBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ContextBuilder builder;
    public N and() {
      return (N) NamedContextFluentImpl.this.withContext(builder.build());
    }
    public N endContext() {
      return and();
    }
    
  }
  
}
